@@ -19,9 +19,7 @@
 #    along with this program.  If not, see <https://www.gnu.org/licenses/>.
 ###################
 
-"""This package implements a web server to run scripts or 
-executables from the command line and display the result 
-in a web interface.
+"""This tools run scripts and display the result in a Web Interface.
 
 This file write HTML documentation using pydoc."""
 
@@ -30,8 +28,8 @@ __author__ = "Maurice Lambert"
 __author_email__ = "mauricelambert434@gmail.com"
 __maintainer__ = "Maurice Lambert"
 __maintainer_email__ = "mauricelambert434@gmail.com"
-__description__ = """This package implements a web server to run scripts or 
-executables from the command line and display the result in a web interface.
+__description__ = """
+This tools run scripts and display the result in a Web Interface.
 
 This file write HTML documentation using pydoc."""
 __license__ = "GPL-3.0 License"
@@ -62,10 +60,13 @@ def main() -> None:
         sys.exit(1)
 
     COLORS = {
-        "#ffc8d8": "#EEC477",
-        #        "#ee77aa": "#A57927",
-        "#ee77aa": "#C89B48",
-        "#aa55cc": "#4A948C",
+        "#ffc8d8": "#EEC477",  # pink
+        # "#ee77aa": "#A57927",
+        "#ee77aa": "#C89B48",  # pink
+        "#aa55cc": "#75B4AD",  # purple
+        "#7799ee": "#9286C2",  # blue
+        "#55aa55": "#18675F",  # green
+        "#eeaa77": "#A57927",  # orange
     }
 
     filename = sys.argv[1]
@@ -95,7 +96,3 @@ def main() -> None:
 if __name__ == "__main__":
     main()
     sys.exit(0)
-
-
-# ffc8d8: Light pink -> Pale yellow: #EEC477
-# ee77aa: Dark pink  -> Dark yellow: #A57927
