@@ -18,27 +18,28 @@
 
 */
 
-function build_categories (scripts) {
-	let content = document.getElementById("webscripts_content");
-	let categories = {};
-	let script_string;
-	let script;
+function build_categories(scripts) {
+    let content = document.getElementById("webscripts_content");
+    let categories = {};
+    let script_string;
+    let script;
 
-	for (let i in scripts) {
-		script = scripts[i];
+    for (let i in scripts) {
+        script = scripts[i];
 
-		if (script.name !== "/auth/") {
-			script_string = `
+        if (script.name !== "/auth/") {
+            script_string = `
 					<li class="category script_bullet_point"><a class="category script_link inline" href="/web/scripts/${script.name}">${script.name}</a> <p class="description inline">(${script.description})</p></li>
 			`
-		} else {
-			script_string = `
+        } else {
+            script_string = `
 					<li class="category script_bullet_point"><a class="category script_link inline" href="/web/auth/">${script.name}</a> <p class="description inline">(${script.description})</p></li>
 			`
-		}
+        }
 
-		if (script.category !== undefined && categories[script.category] === undefined) {
-			categories[script.category] = `
+        if (script.category !== undefined && categories[script.category] ===
+            undefined) {
+            categories[script.category] = `
 			<div class="category category_content">
 				<h3 class="category category_title">${script.category}</h3>
 
@@ -47,15 +48,17 @@ function build_categories (scripts) {
 					<!---->
 				</ul>
 			</div>
-			`
-		} else if (script.category !== undefined && categories[script.category] !== undefined) {
-			categories[script.category] = categories[script.category].replace("<!---->", script_string + "<!---->");
-		}
-	}
+			`;
+        } else if (script.category !== undefined && categories[script
+            .category] !== undefined) {
+            categories[script.category] = categories[script.category].replace(
+                "<!---->", script_string + "<!---->");
+        }
+    }
 
-	for (let i in categories) {
-		content.innerHTML += categories[i];
-	}
+    for (let i in categories) {
+        content.innerHTML += categories[i];
+    }
 
-	add_button();
-}
+    add_button();
+}
\ No newline at end of file
